/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.flink.tiering.committer;

import org.apache.fluss.config.Configuration;
import org.apache.fluss.lake.committer.CommitterInitContext;
import org.apache.fluss.lake.committer.LakeCommitter;
import org.apache.fluss.metadata.TableInfo;
import org.apache.fluss.metadata.TablePath;

/** The {@link CommitterInitContext} implementation for {@link LakeCommitter}. */
public class TieringCommitterInitContext implements CommitterInitContext {

    private final TablePath tablePath;
    private final TableInfo tableInfo;
    private final Configuration lakeTieringConfig;
    private final Configuration flussClientConfig;

    public TieringCommitterInitContext(
            TablePath tablePath,
            TableInfo tableInfo,
            Configuration lakeTieringConfig,
            Configuration flussClientConfig) {
        this.tablePath = tablePath;
        this.tableInfo = tableInfo;
        this.lakeTieringConfig = lakeTieringConfig;
        this.flussClientConfig = flussClientConfig;
    }

    @Override
    public TablePath tablePath() {
        return tablePath;
    }

    @Override
    public TableInfo tableInfo() {
        return tableInfo;
    }

    @Override
    public Configuration lakeTieringConfig() {
        return lakeTieringConfig;
    }

    @Override
    public Configuration flussClientConfig() {
        return flussClientConfig;
    }
}
